@@ -16,7 +16,7 @@ struct Interface {
 
 fn main() {
   // Create a pool of 4 node workers
-  let mut pool = WorkerPool::setup(4);
+  let mut pool = WorkerPool::setup("examples/worker", 4);
   pool.with_debug(true);
 
   // Payloads
@@ -32,7 +32,7 @@ fn main() {
   // execute the command "getInterfaces" on every file
   // each executed worker will return an array of interfaces (Vec<Interface>)
   let interfaces = pool
-    .perform::<Vec<Interface>, _>("examples/worker", "getInterfaces", files)
+    .perform::<Vec<Interface>, _>("getInterfaces", files)
     .unwrap();
   let interfaces: Vec<Interface> = interfaces
     .into_iter()
